# tsticker

Telegram Sticker Utils | Make Telegram Sticker from CLI

```shell
tsticker login -t <token> -u <user>
tsticker init -n <pack_name> -t <pack_title>
tsticker push
tsticker sync
```

启动时编制索引，需要BotToken，还有名字和ID